=== modified file 'bzrlib/plugins/launchpad/lp_registration.py'
--- bzrlib/plugins/launchpad/lp_registration.py	2007-11-12 21:23:07 +0000
+++ bzrlib/plugins/launchpad/lp_registration.py	2007-11-14 15:03:18 +0000
@@ -99,8 +99,8 @@
 
     def gather_user_credentials(self):
         """Get the password from the user."""
-        config = config.GlobalConfig()
-        self.registrant_email = config.user_email()
+        the_config = config.GlobalConfig()
+        self.registrant_email = the_config.user_email()
         if self.registrant_password is None:
             auth = config.AuthenticationConfig()
             scheme, hostinfo = urlsplit(self.service_url)[:2]
@@ -109,6 +109,7 @@
             # We will reuse http[s] credentials if we can, prompt user
             # otherwise
             self.registrant_password = auth.get_password(scheme, hostinfo,
+                                                         self.registrant_email,
                                                          prompt=prompt)
 
     def send_request(self, method_name, method_params, authenticated):

=== modified file 'bzrlib/plugins/launchpad/test_register.py'
--- bzrlib/plugins/launchpad/test_register.py	2007-10-14 09:52:55 +0000
+++ bzrlib/plugins/launchpad/test_register.py	2007-11-14 15:03:18 +0000
@@ -17,8 +17,15 @@
 import base64
 import os
 from StringIO import StringIO
+import urlparse
 import xmlrpclib
 
+from bzrlib import (
+    config,
+    osutils,
+    tests,
+    ui,
+    )
 from bzrlib.tests import TestCase, TestSkipped
 
 # local import
@@ -130,8 +137,7 @@
     def setUp(self):
         super(TestBranchRegistration, self).setUp()
         # make sure we have a reproducible standard environment
-        if 'BZR_LP_XMLRPC_URL' in os.environ:
-            del os.environ['BZR_LP_XMLRPC_URL']
+        self._captureVar('BZR_LP_XMLRPC_URL', None)
 
     def test_register_help(self):
         """register-branch accepts --help"""
@@ -266,3 +272,55 @@
                 'sftp://bazaar.launchpad.net~bzr/bzr/trunk',
                 'bzr+http://bazaar.launchpad.net~bzr/bzr/trunk',
                 'http://bazaar.launchpad.net~bzr/bzr/trunk'])
+
+
+class TestGatherUserCredentials(tests.TestCaseInTempDir):
+
+    def setUp(self):
+        super(TestGatherUserCredentials, self).setUp()
+        # make sure we have a reproducible standard environment
+        self._captureVar('BZR_LP_XMLRPC_URL', None)
+
+    def test_gather_user_credentials_has_password(self):
+        service = LaunchpadService()
+        service.registrant_password = 'mypassword'
+        # This should be a basic no-op, since we already have the password
+        service.gather_user_credentials()
+        self.assertEqual('mypassword', service.registrant_password)
+
+    def test_gather_user_credentials_from_auth_conf(self):
+        auth_path = config.authentication_config_filename()
+        service = LaunchpadService()
+        g_conf = config.GlobalConfig()
+        g_conf.set_user_option('email', 'Test User <test@user.com>')
+        f = open(auth_path, 'wb')
+        try:
+            scheme, hostinfo = urlparse.urlsplit(service.service_url)[:2]
+            f.write('[section]\n'
+                    'scheme=%s\n'
+                    'host=%s\n'
+                    'user=test@user.com\n'
+                    'password=testpass\n'
+                    % (scheme, hostinfo))
+        finally:
+            f.close()
+        self.assertIs(None, service.registrant_password)
+        service.gather_user_credentials()
+        self.assertEqual('test@user.com', service.registrant_email)
+        self.assertEqual('testpass', service.registrant_password)
+
+    def test_gather_user_credentials_prompts(self):
+        service = LaunchpadService()
+        self.assertIs(None, service.registrant_password)
+        g_conf = config.GlobalConfig()
+        g_conf.set_user_option('email', 'Test User <test@user.com>')
+        stdout = tests.StringIOWrapper()
+        ui.ui_factory = tests.TestUIFactory(stdin='userpass\n',
+                                            stdout=stdout)
+        self.assertIs(None, service.registrant_password)
+        service.gather_user_credentials()
+        self.assertEqual('test@user.com', service.registrant_email)
+        self.assertEqual('userpass', service.registrant_password)
+        self.assertContainsRe(stdout.getvalue(),
+                             'launchpad.net password for test@user\\.com')
+

=== modified file 'bzrlib/tests/test_config.py'
--- bzrlib/tests/test_config.py	2007-10-23 14:31:10 +0000
+++ bzrlib/tests/test_config.py	2007-11-13 22:02:21 +0000
@@ -1133,7 +1133,7 @@
         self.assertEquals(expected_user, user)
         self.assertEquals(expected_password, password)
 
-    def  test_empty_config(self):
+    def test_empty_config(self):
         conf = config.AuthenticationConfig(_file=StringIO())
         self.assertEquals({}, conf._get_config())
         self._got_user_passwd(None, None, conf, 'http', 'foo.net')

